==> pathena-0.3.3.tgz: .pathena/types/source_standard.py <==

from file_type_attribs import add_source_type

# File type classes for source files of standard, commonly used languages
# are defined in this module.  Each entry invokes the function
#     add_source_type(name, specials, *extensions)
# The argument 'specials' is a string of all special characters that the
# language allows in identifiers, that is, any character besides '_' and
# the alphanumerics.  In some cases, special characters are included
# because they are commonly prepended to identifiers even though they
# are not considered part of the identifiers themselves.  This might
# prove to be helpful during searches.


add_source_type('python',  '',    'py')
add_source_type('perl',    '$@%', 'pl')
add_source_type('tcl',     '',    'tcl')
add_source_type('ruby',    '$@',  'rb', 'rbx')
add_source_type('java',    '$',   'java', 'jav')
add_source_type('php',     '$',   'php')
add_source_type('c',       '',    'c', 'h')
add_source_type('cpp',     '',    'cc', 'C', 'cpp', 'cxx')
add_source_type('ada',     '',    'ada')
add_source_type('haskell', "'",   'hs')
add_source_type('sql',     '$#',  'sql')
add_source_type('scheme',  '=<>~.+-*/^&?!$%:', 'scm', 'ss')
add_source_type('lisp',    '=<>~.+-*/^&?!$%@[]{}', 'lisp', 'lsp')
add_source_type('elisp',   '=<>~.+-*/^&?!$%@:{}', 'el')


# Additional file extensions for these types may be declared in the
# user's local Pathena configuration.  This occurs in the file
# ~/.pathena/config/source_custom.py.  The Custom Source Types menu
# item facilitates editing this file.

==> pathena-0.3.4.tgz: .pathena/types/source_standard.py <==

from file_type_attribs import add_source_type

# File type classes for source files of standard, commonly used languages
# are defined in this module.  Each entry invokes the function
#     add_source_type(name, specials, *extensions)
# The argument 'specials' is a string of all special characters that the
# language allows in identifiers, that is, any character besides '_' and
# the alphanumerics.  In some cases, special characters are included
# because they are commonly prepended to identifiers even though they
# are not considered part of the identifiers themselves.  This might
# prove to be helpful during searches.


add_source_type('python',  '',    'py')
add_source_type('perl',    '$@%', 'pl')
add_source_type('tcl',     '',    'tcl')
add_source_type('ruby',    '$@',  'rb', 'rbx')
add_source_type('java',    '$',   'java', 'jav')
add_source_type('php',     '$',   'php')
add_source_type('c',       '',    'c', 'h')
add_source_type('cpp',     '',    'cc', 'cpp', 'cxx')
add_source_type('ada',     '',    'ada')
add_source_type('haskell', "'",   'hs')
add_source_type('sql',     '$#',  'sql')
add_source_type('scheme',  '=<>~.+-*/^&?!$%:', 'scm', 'ss')
add_source_type('lisp',    '=<>~.+-*/^&?!$%@[]{}', 'lisp', 'lsp')
add_source_type('elisp',   '=<>~.+-*/^&?!$%@:{}', 'el')


# Additional file extensions for these types may be declared in the
# user's local Pathena configuration.  This occurs in the file
# ~/.pathena/config/source_custom.py.  The Custom Source Types menu
# item facilitates editing this file.
